# Summary

A collection of helper functions and code used for speeding up Blender 3D Python script development.

Important: This package assumes you are using [Blender's](https://www.blender.org/) the embedded Python interpreter. 
